@@ -3,7 +3,7 @@ package Bundle::WWW::Scraper::ISBN::Drivers;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = "1.00";
+$VERSION = "1.02";
 
 1;
 
@@ -31,6 +31,8 @@ WWW::Scraper::ISBN::Driver  0.18
 
 WWW::Scraper::ISBN::Record
 
+WWW::Scraper::ISBN::A1Books_Driver
+
 WWW::Scraper::ISBN::AmazonDE_Driver
 
 WWW::Scraper::ISBN::AmazonFR_Driver
@@ -39,6 +41,8 @@ WWW::Scraper::ISBN::AmazonUK_Driver
 
 WWW::Scraper::ISBN::AmazonUS_Driver
 
+WWW::Scraper::ISBN::Booktopia_Driver
+
 WWW::Scraper::ISBN::ISBNdb_Driver
 
 WWW::Scraper::ISBN::ISBNnu_Driver
@@ -49,6 +53,8 @@ WWW::Scraper::ISBN::LOC_Driver
 
 WWW::Scraper::ISBN::ORA_Driver
 
+WWW::Scraper::ISBN::OpenLibrary_Driver
+
 WWW::Scraper::ISBN::Pearson_Driver
 
 WWW::Scraper::ISBN::Siciliano_Driver
@@ -81,6 +87,8 @@ WWW::Scraper::ISBN::TWYlib_Driver
 
 WWW::Scraper::ISBN::Wheelers_Driver
 
+WWW::Scraper::ISBN::WordPower_Driver
+
 WWW::Scraper::ISBN::Yahoo_Driver
 
 =head1 BUGS, PATCHES & FIXES
